Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
SchemaFilename StringList `yaml:"schema,omitempty"`
Model config.PackageConfig `yaml:"model,omitempty"`
AutoBind []string `yaml:"autobind"`
Client config.PackageConfig `yaml:"client,omitempty"`
Federation config.PackageConfig `yaml:"federation,omitempty"`
Models config.TypeMap `yaml:"models,omitempty"`
Endpoint *EndPointConfig `yaml:"endpoint,omitempty"`
Generate *GenerateConfig `yaml:"generate,omitempty"`
Query []string `yaml:"query"`
// gqlgen config struct
GQLConfig *config.Config `yaml:"-"`
}
Config extends the gqlgen basic config and represents the config file
func LoadConfig ¶
LoadConfig loads and parses the config gqlgenc config
func LoadConfigFromDefaultLocations ¶
LoadConfigFromDefaultLocations looks for a config file in the specified directory, and all parent directories walking up the tree. The closest config file will be returned.
type EndPointConfig ¶
type EndPointConfig struct {
URL string `yaml:"url"`
Headers map[string]string `yaml:"headers,omitempty"`
}
EndPointConfig are the allowed options for the 'endpoint' config
type GenerateConfig ¶
type GenerateConfig struct {
Prefix *NamingConfig `yaml:"prefix,omitempty"`
Suffix *NamingConfig `yaml:"suffix,omitempty"`
UnamedPattern string `yaml:"unamedPattern,omitempty"`
// Deprecated: not working because it is generated by gqlgen
Query *bool `yaml:"query,omitempty"`
// Deprecated: not working because it is generated by gqlgen
Mutation *bool `yaml:"mutation,omitempty"`
Client *bool `yaml:"client,omitempty"`
ClientInterfaceName *string `yaml:"clientInterfaceName,omitempty"`
NullableInputOmittable bool `yaml:"nullableInputOmittable,omitempty"`
EnableClientJsonOmitemptyTag *bool `yaml:"enableClientJsonOmitemptyTag,omitempty"`
EnableClientJsonOmitzeroTag *bool `yaml:"enableClientJsonOmitzeroTag,omitempty"`
// Deprecated: not working because v1 is deleted. Must use ClientV2
// if true, used client v2 in generate code
ClientV2 bool `yaml:"clientV2,omitempty"`
StructFieldsAlwaysPointers *bool `yaml:"structFieldsAlwaysPointers,omitempty"`
InlineFragmentAlwaysPointers *bool `yaml:"inlineFragmentAlwaysPointers,omitempty"`
OnlyUsedModels *bool `yaml:"onlyUsedModels,omitempty"`
}
func (*GenerateConfig) GetClientInterfaceName ¶
func (c *GenerateConfig) GetClientInterfaceName() *string
func (*GenerateConfig) ShouldGenerateClient ¶
func (c *GenerateConfig) ShouldGenerateClient() bool
type NamingConfig ¶
type StringList ¶
type StringList []string
StringList is a simple array of strings
func (StringList) Has ¶
func (a StringList) Has(file string) bool
Has checks if the strings array has a give value
Click to show internal directories.
Click to hide internal directories.